import React from 'react';
import { Route, Redirect } from 'react-router-dom';
import decode from 'jwt-decode';

import * as routes from './../../constants/routes';
import storageKey from './../../utils/storageKey';

export default ({ component: Component, tokenAuth, access, ...rest }) => (
    <Route
        {...rest}
        render={props => {
            // test
            try {
                const storagedData = localStorage.getItem(storageKey);

                if (access === 'public') {
                    return <Component {...props} />
                }
                
                if (!storagedData || storagedData.exp < Date.now()) {
                    throw new Error(1);
                }

                const user = decode(storagedData);
                const { role } = user; 

                if (access === 'admin-only' && !role) {
                    throw new Error(2)                   
                }

                return <Component {...props} />
            }
            catch ({ message: errorCode }) {
                if (errorCode === '1') {
                    return <Redirect to={routes.SIGN_IN} />
                }
                if (errorCode === '2') {
                    return <div>Permission denied</div>
                }
            }
        }}
    />
)